@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 92 $
+# Revision: $Rev: 105 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -184,7 +184,7 @@ class PicturePreview(PicturePreviewBase):
             pathToPicture = self.basedir # assume relative path
             
             # absolute picture path or linked image
-            if ((pref['filenamePrefix'][0] in ('\\', '/')) or
+            if ((pref['filenamePrefix'][0] in ('/', )) or
                 (pref['filenamePrefix'][:7] in ('http://',))):
                 pathToPicture = ""
 
@@ -198,8 +198,8 @@ class PicturePreview(PicturePreviewBase):
                 self.record['picture'] = u""
 
             # create target directory
-            filename = fjoin(pathToPicture, filename)
-            filedir = dirname(filename)
+            abs_filename = fjoin(pathToPicture, filename)
+            filedir = dirname(abs_filename)
             if (not fexists(filedir)):
                 self.log.info("Creating target directory %s", filedir)
                 try:
@@ -210,8 +210,8 @@ class PicturePreview(PicturePreviewBase):
                     self.record['picture'] = u""
 
             # test if file exists
-            if (fexists(filename)):
-                self.log.warning("Target file %s already exists: overwriting", filename)
+            if (fexists(abs_filename)):
+                self.log.warning("Target file %s already exists: overwriting", abs_filename)
 
             # copy data to target file
             data = IODeviceBuffer()
@@ -219,9 +219,9 @@ class PicturePreview(PicturePreviewBase):
             if (self.img == None):
                 self.log.info("No picture data to save")
             elif (self.img.save(data, pref['imageFormat'])):
-                self.log.debug("Saving linked image %s: %d bytes", filename, data.size())
+                self.log.debug("Saving linked image %s: %d bytes", abs_filename, data.size())
                 try:
-                    f = open(filename, "wb")
+                    f = open(abs_filename, "wb")
                     f.write(data.readAll())
                     f.close
                     data.close()        # free memory
@@ -265,7 +265,7 @@ class PicturePreview(PicturePreviewBase):
             pathToPicture = self.basedir # assume relative path
             
             # absolute picture path or linked image
-            if ((self.record['picture'][0] in ('\\', '/')) or
+            if ((self.record['picture'][0] in ('/',)) or
                 (self.record['picture'][:7] in ('http://',))):
                 pathToPicture = ""
                 
