@@ -1,7 +1,7 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
 # Author:   $Author: merkosh $
-# Revision: $Rev: 104 $
+# Revision: $Rev: 105 $
 ############################################################################
 #    Copyright (C) 2005 by Uwe Mayer                                       #
 #    merkosh@hadiko.de                                                     #
@@ -64,7 +64,7 @@ log.addHandler(hdlr)
 log.setLevel(logging.DEBUG)             # default log level
 
 # output program text-logo
-log.info("lmc.py - LMC Movie Catalogue  $Rev: 104 $ (c) by Uwe Mayer")
+log.info("lmc.py - LMC Movie Catalogue  $Rev: 105 $ (c) by Uwe Mayer")
 
 # load settings
 settings = Settings.Settings()
@@ -106,7 +106,7 @@ fileFilterList = filter(lambda a: a != "", map(lambda a: a[1], fileFormats))
 
 
 #-- utility functions ----------------------------------------------------------
-defaultCaption = "LMC Movie Catalogue ($Rev: 104 $) "
+defaultCaption = "LMC Movie Catalogue ($Rev: 105 $) "
 filenameCaption = lambda a: defaultCaption+" - %s"%basename(a)
 
 
@@ -127,7 +127,7 @@ class LMCMain(LMCWidgetBase):
         self.__file = None              # no file opened so far
         self.lastFolder = pref['defaultPath']
         self.recordCopy = None
-#        self.statusBar = self.statusBar()
+        self.modified = False           # modified metadata or deleted record
         
         # create logging
         self.log = logging.getLogger("LMCMain")
@@ -180,10 +180,11 @@ class LMCMain(LMCWidgetBase):
     def fileSave(self):
         """saves modifications to the opened file"""
         # check for modifications
-        modified = False
-        for rec in self.centralWidget().values():
-            modified = rec.modified()
-            if (modified): break        # early exit
+        modified = self.modified
+        if (not modified):
+            for rec in self.centralWidget().values():
+                modified = rec.modified()
+                if (modified): break    # early exit
             
         # skip saving if not modified
         if (not modified):
@@ -198,6 +199,9 @@ class LMCMain(LMCWidgetBase):
             records.sort( lambda a,b: int(a['number']) -int(b['number']) )
         self.__file.writelines(records)
 
+        # clear internal flag
+        self.modified = False
+
         
     def fileSaveAs(self):
         """handles save-as (new file) process"""
@@ -251,6 +255,9 @@ class LMCMain(LMCWidgetBase):
         # set caption
         self.setCaption(filenameCaption(self.__file.name))
 
+        # clear internal flag
+        self.modified = False
+
 
     def fileNew(self):
         """handles the create-new-file process"""
@@ -413,6 +420,8 @@ class LMCMain(LMCWidgetBase):
         """deletes a record"""
         del self.centralWidget()[self.centralWidget().listViewRecord.currentItem()]
 
+        self.modified = True
+
         if (len(self.centralWidget()) == 0):
             self.__disableMovieDeleteAction()
         
@@ -477,7 +486,7 @@ class LMCMain(LMCWidgetBase):
         self.lastFolder = pref['autoMountPoint']
         # get info
         self.movieGetLocalFromFiles()
-        
+               
         # restore target path
         self.lastFolder = tmp
 
@@ -665,10 +674,11 @@ class LMCMain(LMCWidgetBase):
         # check if currently opened records were modified
         if (self.__file != None):
             # test for modified records
-            modified = False
-            for rec in self.centralWidget().values():
-                modified = rec.modified()
-                if (modified): break    # early exit
+            modified = self.modified
+            if (not modified):
+                for rec in self.centralWidget().values():                
+                    modified = rec.modified()
+                    if (modified): break    # early exit
 
             # offer to save changes
             if (modified):
